@@ -54,7 +54,7 @@ class JunOSDriver:
         self.junos_config_database = optional_args.get(
             "junos_config_database", "committed"
         )
-
+        '''
         # config template
         self.jsnapy_test_yml = """  - {}
         """
@@ -71,6 +71,7 @@ class JunOSDriver:
             check_from_sqlite: yes
             database_name: jsnapy.db  
         """
+        '''
         if self.key_file:
             self.device = Device(
                 hostname,
@@ -251,7 +252,6 @@ class JunOSDriver:
         result = {}
         cmd_result = ""
         invaild_cmd = re.compile('^(request|clear|start|restart).*')
-        get_config = re.compile('^show configuration .*')
         for command in commands:
             if not invaild_cmd.match(command): # if not invaild command predefined
                 #(cmd, _, _) = command.partition("|")
@@ -271,49 +271,56 @@ class JunOSDriver:
                     elif rsp.tag == "rpc":
                         return rsp[0]
                     cmd_result = _process_pipe(command,cmd_result)
-                except:
-                    cmd_result = 'RPC call failed'
+                except Exception as e:
+                    logger.error(str(e))
+                    raise
+                
                 result[command] = cmd_result
             else:
                 result[command] = 'Invalid command'
 
         return result
 
-    def junos_compare(self, commands: List[str] = [''], check = False, format: str='set'):
+    def junos_compare(self, config: str, check = False, format: str='set'):
         diff = ''
         check_result = False
-        config_set = '\n'.join(commands)
-        with Config(self.device, mode='private') as cu: # config exclusive
-            cu.load(config_set, format=format, merge=True) # load config
-            diff = cu.diff(0) # show | compare 
-            if check:
-                check_result = cu.commit_check() # commit check
-            cu.rollback()
+        try:
+            with Config(self.device, mode='private') as cu: # config exclusive
+                cu.load(config, format=format, merge=True) # load config
+                diff = cu.diff(0) # show | compare 
+                if check:
+                    check_result = cu.commit_check() # commit check
+                cu.rollback()
+        except Exception as e:
+            logger.error(str(e))
+            raise
         
         return {
             'diff': diff,
             'check': check_result,
         }
 
-    def junos_commit(self, mode: str = 'exclusive', commands: List[str] = [''], format: str='set', commit_comments: str = '', comfirm: int = 1):
-        config_set = '\n'.join(commands)
+    def junos_commit(self, config: str, mode: str = 'exclusive', format: str='set', commit_comments: str = '', comfirm: int = 1):
         diff = ''
         committed = False
         try:
             with Config(self.device, mode=mode) as cu: # config exclusive
-                cu.load(config_set, format=format, merge=True) # load config
-                cu.commit_check() # commit check
-                diff = cu.diff(0) # show | compare 
-                committed = cu.commit(confirm=comfirm, comment=commit_comments) # commit confirm 1 comment
-                cu.commit_check() # commit check
+                try:
+                    cu.load(config, format=format, merge=True) # load config
+                    cu.commit_check() # commit check
+                    diff = cu.diff(0) # show | compare 
+                    committed = cu.commit(confirm=comfirm, comment=commit_comments) # commit confirm 1 comment
+                    cu.commit_check() # commit check
 
-        except RPCError as e:
-            logger.error(str(e))
-            cu.rollback()
-            cu.unlock()
+                except RPCError as e:
+                    logger.error(str(e))
+                    cu.rollback()
+                    cu.unlock()
+                    raise
 
         except Exception as e:
             logger.error(str(e))
+            raise
 
         return {
             'diff':diff,
@@ -323,15 +330,19 @@ class JunOSDriver:
     def junos_compare_file(self, file_path: str, file_location: str , check = False):
         diff = ''
         check_result = False
-        with Config(self.device, mode='private') as cu: # config exclusive
-            if file_location == 'local':
-                cu.load(path= file_path, merge=True) # load config
-            elif file_location == 'remote':
-                cu.load(url= file_path, merge=True)
-            diff = cu.diff(0) # show | compare 
-            if check:
-                check_result = cu.commit_check() # commit check
-            cu.rollback()
+        try:
+            with Config(self.device, mode='private') as cu: # config exclusive
+                if file_location == 'local':
+                    cu.load(path= file_path, merge=True) # load config
+                elif file_location == 'remote':
+                    cu.load(url= file_path, merge=True)
+                diff = cu.diff(0) # show | compare 
+                if check:
+                    check_result = cu.commit_check() # commit check
+                cu.rollback()
+        except Exception as e:
+            logger.error(str(e))
+            raise
         
         return {
             'diff': diff,
@@ -343,22 +354,26 @@ class JunOSDriver:
         committed = False
         try:
             with Config(self.device, mode=mode) as cu: # config exclusive
-                if file_location == 'local':
-                    cu.load(path= file_path, merge=True) # load config
-                elif file_location =='remote':
-                    cu.load(url= file_path, merge=True)
-                cu.commit_check() # commit check
-                diff = cu.diff(0) # show | compare 
-                committed = cu.commit(confirm=comfirm, comment=commit_comments) # commit confirm 1 comment
-                cu.commit_check() # commit check
+                try:
+                    if file_location == 'local':
+                        cu.load(path= file_path, merge=True) # load config
+                    elif file_location =='remote':
+                        cu.load(url= file_path, merge=True)
+                    cu.commit_check() # commit check
+                    diff = cu.diff(0) # show | compare 
+                    committed = cu.commit(confirm=comfirm, comment=commit_comments) # commit confirm 1 comment
+                    cu.commit_check() # commit check
 
-        except RPCError as e:
-            logger.error(str(e))
-            cu.rollback()
-            cu.unlock()
+                except RPCError as e:
+                    logger.error(str(e))
+                    cu.rollback()
+                    cu.unlock()
+                    raise
+            
 
         except Exception as e:
             logger.error(str(e))
+            raise
 
         return {
             'diff':diff,
@@ -366,12 +381,18 @@ class JunOSDriver:
         }
 
     def junos_rpc(self,rpc: str, to_str = 1, **kwargs):
-        method_to_call = getattr(self.device.rpc, rpc)
-        result = method_to_call(**kwargs)
-        if to_str:
-            result = etree.tostring(result, encoding="unicode", method="text", with_tail=False)
-        return result
+        try:
+            method_to_call = getattr(self.device.rpc, rpc)
+            result = method_to_call(**kwargs)
+            if to_str:
+                result = etree.tostring(result, encoding="unicode", method="text", with_tail=False)
 
+        except Exception as e:
+            logger.error(str(e))
+            raise
+
+        return result
+    '''
     def jsnapy_pre(self, jsnapy_test: List[str]):
         # get all check yml and output to file, will use it when post check
         device_test = ''
@@ -382,13 +403,13 @@ class JunOSDriver:
         config_host = self.jsnapy_data.format(
             self.hostname, self.username, self.password, device_test)
         snappre = self.js.snap(config_host, "pre")
-        '''
+    
         # To_do: nothing to output, maybe get from db from file
         for val in snappre:
             with open(host_pre_result, 'w') as f:
                 f.write(json.dumps(dict(val.test_details), indent=4))
         option: get from log
-        '''
+
 
 
     def jsnapy_post(self,jsnapy_test: List[str]):
@@ -422,7 +443,7 @@ class JunOSDriver:
             result.append(dict(val.test_details))
 
         return result
-
+    '''
     def load_junos_view(self, view_path):
         try:
             with open(view_path) as f:
